@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/classes.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2007. 
+ * Copyright (c) Tuomo Valkonen 1999-2008. 
  *
  * See the included file LICENSE for details.
  */
@@ -31,6 +31,8 @@ INTRCLASS(WGroupWS);
 INTRCLASS(WPHolder);
 INTRCLASS(WMPlexPHolder);
 INTRCLASS(WFramedPHolder);
+INTRCLASS(WGroupPHolder);
+INTRCLASS(WGroupedPHolder);
 
 INTRSTRUCT(WStacking);
 INTRSTRUCT(WLListNode);
