@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/eventh.c
  *
- * Copyright (c) Tuomo Valkonen 1999-2007. 
+ * Copyright (c) Tuomo Valkonen 1999-2008. 
  *
  * See the included file LICENSE for details.
  */
@@ -307,8 +307,10 @@ void ioncore_handle_enter_window(XEvent *ev)
     XEnterWindowEvent *eev=&(ev->xcrossing);
     WRegion *reg=NULL;
     
-    if(ioncore_g.input_mode!=IONCORE_INPUTMODE_NORMAL)
+    if(ioncore_g.input_mode!=IONCORE_INPUTMODE_NORMAL ||
+       ioncore_g.no_mousefocus){
         return;
+    }
         
     if(eev->mode!=NotifyNormal && !ioncore_g.warp_enabled)
         return;
