@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/focus.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2007. 
+ * Copyright (c) Tuomo Valkonen 1999-2008. 
  *
  * See the included file LICENSE for details.
  */
@@ -39,9 +39,10 @@ extern void region_lost_focus(WRegion *reg);
 
 /* May reg transfer focus to its children? */
 extern bool region_may_control_focus(WRegion *reg);
+extern bool region_manager_is_focusnext(WRegion *reg);
 
 /* Does reg have focus? */
-extern bool region_is_active(WRegion *reg);
+extern bool region_is_active(WRegion *reg, bool pseudoact_ok);
 
 /* Focus history */
 extern void region_focuslist_remove_with_mgrs(WRegion *reg);
