@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/frame-draw.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2007. 
+ * Copyright (c) Tuomo Valkonen 1999-2008. 
  *
  * See the included file LICENSE for details.
  */
@@ -14,12 +14,13 @@
 
 extern void frame_draw(const WFrame *frame, bool complete);
 extern void frame_draw_bar(const WFrame *frame, bool complete);
-extern void frame_recalc_bar(WFrame *frame);
+extern void frame_recalc_bar(WFrame *frame, bool complete);
 extern void frame_bar_geom(const WFrame *frame, WRectangle *geom);
 extern void frame_border_geom(const WFrame *frame, WRectangle *geom);
 extern void frame_border_inner_geom(const WFrame *frame, WRectangle *geom);
 extern void frame_brushes_updated(WFrame *frame);
 extern void frame_managed_geom(const WFrame *frame, WRectangle *geom);
+extern int frame_shaded_height(const WFrame *frame);
 
 extern void frame_initialise_gr(WFrame *frame);
 extern void frame_release_brushes(WFrame *frame);
@@ -38,6 +39,5 @@ extern void frame_setup_dragwin_style(WFrame *frame, GrStyleSpec *spec, int tab)
 
 extern void frame_inactivated(WFrame *frame);
 extern void frame_activated(WFrame *frame);
-extern void frame_quasiactivity_change(WFrame *frame);
 
 #endif /* ION_IONCORE_FRAME_DRAW_H */
