@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/frame.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2007. 
+ * Copyright (c) Tuomo Valkonen 1999-2008. 
  *
  * See the included file LICENSE for details.
  */
@@ -39,7 +39,10 @@ typedef enum{
     FRAME_MODE_TILED,
     FRAME_MODE_TILED_ALT,
     FRAME_MODE_FLOATING,
-    FRAME_MODE_TRANSIENT
+    FRAME_MODE_TRANSIENT,
+    FRAME_MODE_UNKNOWN_ALT,
+    FRAME_MODE_FLOATING_ALT,
+    FRAME_MODE_TRANSIENT_ALT
 } WFrameMode;
 
 typedef enum{
@@ -116,15 +119,11 @@ extern int frame_default_index(WFrame *frame);
 extern void frame_managed_notify(WFrame *frame, WRegion *sub, WRegionNotify how);
 extern bool frame_managed_rqdispose(WFrame *frame, WRegion *reg);
 
-extern void ioncore_frame_quasiactivation_notify(WRegion *reg, WRegionNotify how);
-
 extern WPHolder *frame_prepare_manage_transient(WFrame *frame,
                                                 const WClientWin *transient,
                                                 const WManageParams *param,
                                                 int unused);
 
-extern bool frame_rescue_clientwins(WFrame *frame, WRescueInfo *info);
-
 /* Save/load */
 extern ExtlTab frame_get_configuration(WFrame *frame);
 extern WRegion *frame_load(WWindow *par, const WFitParams *fp, ExtlTab tab);
@@ -132,4 +131,6 @@ extern void frame_do_load(WFrame *frame, ExtlTab tab);
 
 extern WHook *frame_managed_changed_hook;
 
+extern WFrameMode framemode_unalt(WFrameMode mode);
+
 #endif /* ION_IONCORE_FRAME_H */
