@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/framedpholder.h
  *
- * Copyright (c) Tuomo Valkonen 2005-2007. 
+ * Copyright (c) Tuomo Valkonen 2005-2008. 
  *
  * See the included file LICENSE for details.
  */
@@ -32,6 +32,7 @@ DECLCLASS(WFramedPHolder){
     WPHolder ph;
     WPHolder *cont;
     WFramedParam param;
+    Watch frame_watch;
 };
 
 
@@ -45,7 +46,7 @@ extern void framedpholder_deinit(WFramedPHolder *ph);
 
 extern bool framedpholder_do_goto(WFramedPHolder *ph);
 
-extern WPHolder *framedpholder_do_root(WFramedPHolder *ph);
+extern bool framedpholder_stale(WFramedPHolder *ph);
 
 extern WRegion *framedpholder_do_target(WFramedPHolder *ph);
 
