@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/grouppholder.h
  *
- * Copyright (c) Tuomo Valkonen 2005-2007. 
+ * Copyright (c) Tuomo Valkonen 2005-2008. 
  *
  * See the included file LICENSE for details.
  */
@@ -13,13 +13,14 @@
 #include <ioncore/pholder.h>
 #include "group.h"
 
-INTRCLASS(WGroupPHolder);
 
 DECLCLASS(WGroupPHolder){
     WPHolder ph;
-    Watch group_watch;
+    WGroup *group;
     Watch stack_above_watch;
     WGroupAttachParams param;
+    WGroupPHolder *next, *prev;
+    WPHolder *recreate_pholder;
 };
 
 extern WGroupPHolder *create_grouppholder(WGroup *group, 
@@ -43,4 +44,8 @@ extern WRegion *grouppholder_do_attach(WGroupPHolder *ph, int flags,
 extern WGroupPHolder *group_managed_get_pholder(WGroup *group, 
                                                 WRegion *mgd);
 
+extern void grouppholder_do_unlink(WGroupPHolder *ph);
+extern void grouppholder_do_link(WGroupPHolder *ph, WGroup *group, 
+                                 WRegion *stack_above);
+
 #endif /* ION_IONCORE_GROUPPHOLDER_H */
