@@ -1,7 +1,7 @@
 --
 -- ion/share/ioncore_tabnum.lua -- Ioncore tab numbering support
 -- 
--- Copyright (c) Tuomo Valkonen 2007.
+-- Copyright (c) Tuomo Valkonen 2007-2008.
 --
 -- See the included file LICENSE for details.
 --
@@ -11,8 +11,12 @@ ioncore.tabnum={}
 local framestate={}
 
 local function do_show(frame)
-    frame:set_grattr('numbered', 'set')
-    framestate[frame]='set'
+    if obj_exists(frame) then
+        frame:set_grattr('numbered', 'set')
+        framestate[frame]='set'
+    else
+        framestate[frame]=nil
+    end
 end
 
 --DOC
@@ -38,7 +42,9 @@ function ioncore.tabnum.clear()
     
     for f, s in pairs(st) do
         if s=='set' then
-            f:set_grattr('numbered', 'unset')
+            if obj_exists(f) then
+                f:set_grattr('numbered', 'unset')
+            end
         elseif obj_is(s, "WTimer") then
             s:reset()
         end
