@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/mplexpholder.h
  *
- * Copyright (c) Tuomo Valkonen 2005-2007. 
+ * Copyright (c) Tuomo Valkonen 2005-2008. 
  *
  * See the included file LICENSE for details.
  */
@@ -18,7 +18,7 @@
 
 DECLCLASS(WMPlexPHolder){
     WPHolder ph;
-    Watch mplex_watch;
+    WMPlex *mplex;
     WFramedPHolder *recreate_pholder; /* only on first of list */
     WLListNode *after;
     WMPlexPHolder *next, *prev;
@@ -26,8 +26,7 @@ DECLCLASS(WMPlexPHolder){
 };
 
 
-/* If 'after' is set, it is used, otherwise 'or_after', 
- * and finally 'or_layer' if this is also unset
+/* If 'either_st' is set, it is used, otherwise 'or_param', is used. 
  */
 
 extern WMPlexPHolder *create_mplexpholder(WMPlex *mplex, 
@@ -39,14 +38,12 @@ extern bool mplexpholder_init(WMPlexPHolder *ph,
                               WMPlexAttachParams *or_param);
 extern void mplexpholder_deinit(WMPlexPHolder *ph);
 
-extern int mplexpholder_layer(WMPlexPHolder *ph);
-
 extern WRegion *mplexpholder_do_attach(WMPlexPHolder *ph, int flags,
                                        WRegionAttachData *data);
 
 extern bool mplexpholder_do_goto(WMPlexPHolder *ph);
 
-extern WPHolder *mplexpholder_do_root(WMPlexPHolder *ph);
+extern bool mplexpholder_stale(WMPlexPHolder *ph);
 
 extern WRegion *mplexpholder_do_target(WMPlexPHolder *ph);
 
@@ -60,10 +57,12 @@ extern void mplex_move_phs(WMPlex *mplex, WLListNode *node,
                            WMPlexPHolder *after,
                            WLListNode *or_after);
 extern void mplex_move_phs_before(WMPlex *mplex, WLListNode *node);
+extern void mplex_migrate_phs(WMPlex *src, WMPlex *dst);
+extern void mplex_flatten_phs(WMPlex *mplex);
 
 extern WMPlexPHolder *mplex_managed_get_pholder(WMPlex *mplex, 
                                                 WRegion *mgd);
-extern WMPlexPHolder *mplex_get_rescue_pholder_for(WMPlex *mplex, 
-                                                       WRegion *mgd);
+extern WPHolder *mplex_get_rescue_pholder_for(WMPlex *mplex, 
+                                              WRegion *mgd);
 
 #endif /* ION_IONCORE_MPLEXPHOLDER_H */
