@@ -377,8 +377,11 @@ void ioncore_screen_activity_notify(WRegion *reg, WRegionNotify how)
     if(how==ioncore_g.notifies.activity){
         screen_update_notifywin(region_screen_of(reg));
     }else if(how==ioncore_g.notifies.name){
+        WScreen *scr=region_screen_of(reg);
         if(region_is_activity(reg))
-            screen_update_notifywin(region_screen_of(reg));
+            screen_update_notifywin(scr);
+        if((WRegion*)scr==REGION_MANAGER(reg))
+            screen_do_update_infowin(scr);
     }
 }
 
