@@ -1,7 +1,7 @@
 /*
  * ion/mod_statusbar/statusbar.c
  *
- * Copyright (c) Tuomo Valkonen 1999-2007. 
+ * Copyright (c) Tuomo Valkonen 1999-2008. 
  *
  * See the included file LICENSE for details.
  */
@@ -76,8 +76,6 @@ bool statusbar_init(WStatusBar *p, WWindow *parent, const WFitParams *fp)
 
     region_add_bindmap((WRegion*)p, mod_statusbar_statusbar_bindmap);
     
-    ((WRegion*)p)->flags|=REGION_SKIP_FOCUS;
-
     LINK_ITEM(statusbars, p, sb_next, sb_prev);
     
     return TRUE;
@@ -637,7 +635,8 @@ bool statusbar_fitrep(WStatusBar *sb, WWindow *par, const WFitParams *fp)
     bool wchg=(REGION_GEOM(sb).w!=fp->g.w);
     bool hchg=(REGION_GEOM(sb).h!=fp->g.h);
     
-    window_do_fitrep(&(sb->wwin), par, &(fp->g));
+    if(!window_fitrep(&(sb->wwin), par, fp))
+        return FALSE;
     
     if(wchg || hchg){
         statusbar_calculate_xs(sb);
